pub struct XtremIOConfig {
pub endpoint: String,
pub user: String,
pub password: String,
pub certificate: Option<String>,
pub root_certificate: Option<String>,
pub region: String,
}Fields
endpoint: StringThe scaleio endpoint to use
user: Stringpassword: StringThis gets replaced with the token at runtime
certificate: Option<String>Optional certificate file to use against the server der encoded
root_certificate: Option<String>Optional root certificate file to use against the server der encoded
region: StringThe region this cluster is located in