pub struct Vnx { /* private fields */ }Implementations
Sourceimpl Vnx
impl Vnx
pub fn new(client: &Client, config: VnxConfig) -> MetricsResult<Self>
pub fn logout_request(&self) -> MetricsResult<()>
pub fn mover_network_stats_request( &mut self, mover_id: &str, ) -> MetricsResult<Vec<TsPoint>>
pub fn mover_cifs_stats_request( &mut self, mover_id: &str, ) -> MetricsResult<Vec<TsPoint>>
pub fn mover_resource_stats_request( &mut self, mover_id: &str, ) -> MetricsResult<Vec<TsPoint>>
pub fn mover_nfs_stats_request( &mut self, mover_id: &str, ) -> MetricsResult<Vec<TsPoint>>
pub fn storage_pool_query_request(&mut self) -> MetricsResult<StoragePools>
pub fn disk_info_request( &mut self, mover_id: &str, ) -> MetricsResult<Vec<TsPoint>>
pub fn cifs_server_request(&mut self) -> MetricsResult<Vec<TsPoint>>
pub fn filesystem_capacity_request(&mut self) -> MetricsResult<Vec<TsPoint>>
pub fn filesystem_usage_request(&mut self) -> MetricsResult<Vec<TsPoint>>
Sourcepub fn mount_listing_request(
&mut self,
t: DateTime<Utc>,
) -> MetricsResult<Vec<TsPoint>>
pub fn mount_listing_request( &mut self, t: DateTime<Utc>, ) -> MetricsResult<Vec<TsPoint>>
A VNX mount is identified by the Data Mover ID and the mount path (This is a directory where the file system is mounted. In VNX terminology it is called the mount point.) in the root file system of the mover or VDM. A mount export is identified by the Data Mover or VDM on which the file system is mounted and the mount path.
Reads an XML file to parse which servers mounted the shares The XML file is a dump created by the cli commands run on the control array and exported onto the local system. This alternative has been choosen because vnx APIs donot expose this information. With Unity, it may be available via REST.